@@ -6,9 +6,9 @@
 
 #pragma once
 
-#include <QDialog>
+#include "kleo_export.h"
 
-#include <kleo_export.h>
+#include <QDialog>
 
 #ifdef HAVE_PIMTEXTEDIT
 #include <KPIMTextEdit/RichTextEditorWidget>
@@ -33,7 +33,7 @@ class KLEO_EXPORT AuditLogViewer : public QDialog
 public:
     explicit AuditLogViewer(const QString &log, QWidget *parent = nullptr);
 
-    ~AuditLogViewer();
+    ~AuditLogViewer() override;
 
     void setAuditLog(const QString &log);
 
